==> stripe-android-12.9.0-sources.jar: com/stripe/android/view/ShippingMethodAdapter.kt <==
package com.stripe.android.view

import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import com.stripe.android.model.ShippingMethod
import java.util.ArrayList

/**
 * Adapter that populates a list with shipping methods
 */
internal class ShippingMethodAdapter :
    RecyclerView.Adapter<ShippingMethodAdapter.ShippingMethodViewHolder>() {

    private var shippingMethods: List<ShippingMethod> = ArrayList()
    private var selectedIndex = 0

    init {
        setHasStableIds(true)
    }

    val selectedShippingMethod: ShippingMethod?
        get() = shippingMethods[selectedIndex]

    override fun getItemCount(): Int {
        return shippingMethods.size
    }

    override fun getItemId(position: Int): Long {
        return shippingMethods[position].hashCode().toLong()
    }

    override fun onCreateViewHolder(viewGroup: ViewGroup, i: Int): ShippingMethodViewHolder {
        return ShippingMethodViewHolder(ShippingMethodView(viewGroup.context), this)
    }

    override fun onBindViewHolder(holder: ShippingMethodViewHolder, i: Int) {
        holder.setShippingMethod(shippingMethods[i])
        holder.setSelected(i == selectedIndex)
    }

    fun setShippingMethods(
        shippingMethods: List<ShippingMethod>?,
        defaultShippingMethod: ShippingMethod?
    ) {
        this.shippingMethods = shippingMethods ?: emptyList()
        selectedIndex = if (defaultShippingMethod == null) {
            0
        } else {
            this.shippingMethods.indexOf(defaultShippingMethod)
        }
        notifyDataSetChanged()
    }

    fun onShippingMethodSelected(selectedIndex: Int) {
        val previousSelectedIndex = this.selectedIndex
        this.selectedIndex = selectedIndex

        notifyItemChanged(previousSelectedIndex)
        notifyItemChanged(selectedIndex)
    }

    internal fun setSelected(shippingMethod: ShippingMethod) {
        val previouslySelectedIndex = selectedIndex
        selectedIndex = shippingMethods.indexOf(shippingMethod)
        if (previouslySelectedIndex != selectedIndex) {
            notifyItemChanged(previouslySelectedIndex)
            notifyItemChanged(selectedIndex)
        }
    }

    internal class ShippingMethodViewHolder constructor(
        private val shippingMethodView: ShippingMethodView,
        adapter: ShippingMethodAdapter
    ) : RecyclerView.ViewHolder(shippingMethodView) {
        init {
            shippingMethodView.setOnClickListener {
                adapter.onShippingMethodSelected(adapterPosition)
            }
        }

        fun setShippingMethod(shippingMethod: ShippingMethod) {
            shippingMethodView.setShippingMethod(shippingMethod)
        }

        fun setSelected(selected: Boolean) {
            shippingMethodView.isSelected = selected
        }
    }
}

==> stripe-android-16.1.0-sources.jar: com/stripe/android/view/ShippingMethodAdapter.kt <==
package com.stripe.android.view

import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import com.stripe.android.model.ShippingMethod

/**
 * Adapter that populates a list with shipping methods
 */
internal class ShippingMethodAdapter :
    RecyclerView.Adapter<ShippingMethodAdapter.ShippingMethodViewHolder>() {
    internal var onShippingMethodSelectedCallback: (ShippingMethod) -> Unit = {}

    internal var shippingMethods: List<ShippingMethod> = emptyList()
        set(value) {
            // reset selected
            selectedIndex = 0
            field = value
            notifyDataSetChanged()
        }

    @JvmSynthetic
    internal var selectedIndex = 0
        set(value) {
            if (field != value) {
                // only notify change if the field's value is changing
                notifyItemChanged(field)
                notifyItemChanged(value)
                field = value

                onShippingMethodSelectedCallback(shippingMethods[value])
            }
        }

    init {
        setHasStableIds(true)
    }

    val selectedShippingMethod: ShippingMethod?
        get() = shippingMethods.getOrNull(selectedIndex)

    override fun getItemCount(): Int {
        return shippingMethods.size
    }

    override fun getItemId(position: Int): Long {
        return shippingMethods[position].hashCode().toLong()
    }

    override fun onCreateViewHolder(viewGroup: ViewGroup, i: Int): ShippingMethodViewHolder {
        return ShippingMethodViewHolder(ShippingMethodView(viewGroup.context))
    }

    override fun onBindViewHolder(holder: ShippingMethodViewHolder, i: Int) {
        holder.setShippingMethod(shippingMethods[i])
        holder.setSelected(i == selectedIndex)
        holder.shippingMethodView.setOnClickListener {
            selectedIndex = holder.adapterPosition
        }
    }

    internal fun setSelected(shippingMethod: ShippingMethod) {
        selectedIndex = shippingMethods.indexOf(shippingMethod)
    }

    internal class ShippingMethodViewHolder constructor(
        internal val shippingMethodView: ShippingMethodView
    ) : RecyclerView.ViewHolder(shippingMethodView) {

        fun setShippingMethod(shippingMethod: ShippingMethod) {
            shippingMethodView.setShippingMethod(shippingMethod)
        }

        fun setSelected(selected: Boolean) {
            shippingMethodView.isSelected = selected
        }
    }
}
